#
# spec file for package juk
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without released
Name:           juk
Version:        25.04.2
Release:        1.1
Summary:        Jukebox
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/juk
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6Completion) >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6DBusAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6DocTools) >= %{kf6_version}
BuildRequires:  cmake(KF6GlobalAccel) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6IconThemes) >= %{kf6_version}
BuildRequires:  cmake(KF6JobWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6KIO) >= %{kf6_version}
BuildRequires:  cmake(KF6Notifications) >= %{kf6_version}
BuildRequires:  cmake(KF6StatusNotifierItem) >= %{kf6_version}
BuildRequires:  cmake(KF6TextWidgets) >= %{kf6_version}
BuildRequires:  cmake(KF6Wallet) >= %{kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6WindowSystem) >= %{kf6_version}
BuildRequires:  cmake(KF6XmlGui) >= %{kf6_version}
BuildRequires:  cmake(Phonon4Qt6)
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Network) >= %{qt6_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
BuildRequires:  pkgconfig(taglib)

%description
Jukebox and music manager by KDE

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --with-html --all-name

%files
%license COPYING
%doc %lang(en) %{_kf6_htmldir}/en/juk/
%{_kf6_applicationsdir}/org.kde.juk.desktop
%{_kf6_appstreamdir}/org.kde.juk.appdata.xml
%{_kf6_bindir}/juk
%{_kf6_dbusinterfacesdir}/org.kde.juk.*
%{_kf6_iconsdir}/hicolor/*/apps/juk.*
%{_kf6_notificationsdir}/juk.notifyrc
%{_kf6_sharedir}/juk/
%dir %{_kf6_sharedir}/kio
%dir %{_kf6_sharedir}/kio/servicemenus
%{_kf6_sharedir}/kio/servicemenus/jukservicemenu.desktop

%files lang -f %{name}.lang
%exclude %{_kf6_htmldir}/en/juk/

%changelog
* Tue Jun  3 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.2/
- No code change since 25.04.1
* Wed May  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.1/
- Changes since 25.04.0:
  * flatpak: Update runtime version
* Mon Apr 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/25.04.0/
- No code change since 25.03.90
* Sat Mar 29 2025 Christophe Marin <christophe@krop.fr>
- Update to 25.03.90
  * New feature release
- Changes since 24.12.3:
  * Raise window on activation
  * Remove invalid parameter
  * Set window icon
  * lyricswidget do not display the string "I18N_ARGUMENT_MISSING"
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- No code change since 24.12.1
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- No code change since 24.12.0
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- No code change since 24.11.80
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Fix CLion issues
  * Place CoverColumn last, to not interfere with other columns (kde#482210)
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- Changes since 24.08.0:
  * snapcraft: add home plug for access to Music folder.
  * snapcraft: Build stable branch.
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * org.kde.juk.appdata.xml : Fix minor typo in description.
  * Add developer_name and launchable to appdata
  * Enforce passing tests
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- No code change since 24.05.0
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.04.80
  * New feature release
- Changes since 24.02.2:
  * Fix build with taglib 2
* Tue Apr  9 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.2/
- No code change since 24.02.1
* Tue Mar 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.02.1/
- No code change since 24.02.0
* Fri Feb 23 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.02.0
  * New feature release
- No code change since 24.01.95
* Wed Feb 21 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.01.95
  * https://kde.org/announcements/megarelease/6/rc2/
- Drop patch, merged upstream:
  * 0001-Fix-build-with-taglib-2.patch
* Tue Feb 20 2024 Christophe Marin <christophe@krop.fr>
- Add patch to fix build with taglib 2:
  * 0001-Fix-build-with-taglib-2.patch
* Tue Dec  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.4
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.4/
- No code change since 23.08.3
* Tue Nov  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.3/
- Changes since 23.08.2:
  * snapcraft: intial import snapcraft files.
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- No code change since 23.08.0
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- No code change since 23.07.80
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- No code change since 23.04.2
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- No code change since 23.04.1
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- No code change since 23.04.0
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Changes since 21.12.3:
  * CI: Use modern CI tooling
  * Port service menu to new install location
  * Remove bogus kitemmodels dependency
  * Port deprecated use of KLineEdit for password to KPasswordLineEdit.
  * Remove unneeded use of deprecated KDirList auto-error handling.
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- No code change since 21.12.2
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- No code change since 21.12.1
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- No code change since 21.12.0
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Remove bogus kitemmodels dependency
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Remove unused includes
  * mimeData signature was changed in qt6 (scripted)
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- No code change since 21.08.1
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- No code change since 21.07.80
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Changes since 21.04.3:
  * Take into account that some languages use different
    plural rules for n > 4
  * Add "Open Containing Folder" action
  * Add a user-defined literal to grab themed icons and port to use it.
  * lyrics: Disable lyrics requests as the site seems to be down.
  * playlistsplitter: Use compile-time signal/slot connections.
  * Add a user-defined literal for our action collection.
  * playlistsplitter: Minor cleanups again.
  * playlist: Ensure playing track is visible when it changes. (kde#356224)
  * playqueue: Use an appropriate icon for rebadged "remove playlist" action. (kde#336250)
  * JuK: More minor cleanups.
  * playermanager: Cleanup before I work on some bugs in track playback.
  * mediafiles: Make Playlist Save As file type message translatable. (kde#413065)
  * playlist: Modernization and cleanup of playlist code.
  * playlist: Modernize signal/slot connections here too.
  * playlistbox: Remove most string-based signal/slot connections.
  * playlistbox: Use QVector instead of QList for list of playlists.
  * playlistbox: Modernize code a bit.
  * playlistcollection: Minor cleanups, rename object().
  * ui: Focus the playlist search line edit on startup.
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- Changes since 21.04.1:
  * Add missing Qt5Concurrent to target_link_libraries
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- No code change since 21.04.0
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Too many changes since 21.03.80, only listing bugfixes:
  * Improve track sequencing by removing the track sequencing classes. (kde#100356)
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * ensure systray tooltip updates on track change (kde#412009)
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * filerenamer: Prevent creating track name folders
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- No code change since 20.12.1
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- No code change since 20.12.0
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- Changes since 20.11.90:
  * ensure systray tooltip updates on track change (kde#412009)
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Changes since 20.08.3:
  * Port away from deprecated Qt::MidButton
  * Port away from deprecated random generator and QString function.
  * cgit -> invent
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- No code change since 20.08.2
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- No code change since 20.08.1
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- No code change since 20.08.0
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- No code change since 20.04.3
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- Changes since 20.04.2:
  * Fix CMake module search
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * playlist: Fix crasher with playlists using reserved columns. (kde#420718)
* Fri May  1 2020 Wolfgang Bauer <wbauer@tmo.at>
- Add cmake(KF5ItemModels) BuildRequires on Leap 15 to fix build
  (needed when building with Qt < 5.13.0)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- No code change since 20.03.90
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * appdata: use canonical cdn screenshot location
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- No code change since 19.12.1
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
  * PlayerManager: Unify volume slots (kde#405973)
  * Save config after it is closed by the window manager (kde#359681)
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * taglib: Remove deprecated code.
  * Port to QElapsedTimer
  * Port some deprecated method
  * Port setMargins -> setContentsMargins
  * install notifier file in correct directory
  * Consistency in About window: Use same URL as appdata file and unify some wording
  * Limit to one instance
  * HiDPI support for slider
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Add DesktopEntry to notifyrc
  * install notifier file in correct directory
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Ensure CollectionList cache is saved on shutdown.
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- Changes since 19.07.90:
  * Adjust lyrics to use new URLs. (kde#406791)
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- Changes since 19.07.80:
  * Fix folder dialog always opens even if it is set and not empty
  * Fix compilation with -DQT_NO_CAST_TO_ASCII
  * Fix taglib includes to match the way taglib was meant to be used: #include <tag.h>
  * Rename tag.* to juktag.* to avoid a clash with taglib's tag.h
  * Mark taglib includes as SYSTEM
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * appdata: fix the URLs (mostly https-related)
  * renamer: Stretch the content, not the label of confirm dialog.
  * Found a few more compiler warnings to fix [-Wsuggest-override].
  * Bump copyright year
  * Finish removing deprecated code.
  * Remove deprecated code, fix NowPlaying bar height.
  * Remove broken/unused MusicBrainz feature and code.
  * A few more FileRenamer cleanups since I was there.
  * Remove deprecated use of QSignalMapper.
  * Remove more compiler warnings for deprecated functions/uses.
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Make the track title selectable
  * m3u: Add M3U tracks to playlist in the order provided in the file. (kde#408657)
  * renamer: Fix missing accept button in confirm dialog. (kde#408376)
  * Fix drag-and-drop of playlist items onto a playlist icon. (kde#392705)
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Add 'override' decl to fix compiler warnings, fix drag-and-drop.
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Fix taglib detection on Windows
  * Fix crash with threaded file loading.
  * Fix typo README.md
  * Add README.md
  * Simplify Playlist constructors and cleanup header.
  * Remove dead code for playlist tool tip.
  * Add cover art support for Ogg formats (Opus, Vorbis)
  * Remove needless event filter, add alt. row colors, sane column weights.
  * Remove debug spam for power management.
  * Prefer QVector to QList for most auxiliary lists.
  * Apply some cleanup to file loading code.
  * Use a thread pool for the threaded music loader.
  * Move initial music load to a separate thread.
  * scrobbler: Don't prompt to unlock KWallet if not using scrobbler.
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix displaying covers from cover.jpg files
  * Fix crash in filtering playlist to playing album/artist. (kde#402355)
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * ci: enable freebsd platform
  * ci: add the template for creating the flatpak
  * ci: it seems recursive include is not supported
  * Add the Gitlab CI configuration
  * Port sort function for list of playlists to KF5. (kde#402398)
  * Force sorting on so that special playlist sort to top.
  * Fix the "Show Columns" menu to show correct state on startup.
  * Disable tag updating from inline editor.
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * scrobbler: fix missing QNetworkAccessManager when session active.
* Wed Dec  5 2018 Jan Engelhardt <jengelh@inai.de>
- Remove ldconfig calls as there are no libraries.
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * hidpi: Port remaining icon uses to use QIcon for HiDPI support.
  * hidpi: Mark cover art as being at native display resolution.
  * Enable Qt support for High DPI icons.
  * Add donation url to appdata
  * PlayerManager: Also update current track seek when track changes.
  * Do not auto-save playlists just because play queue changes.
  * playlistbox: Do not hardcode icon sizes in playlist item icon.
  * PlayerManager: Queue up next tracks instead of stop/play cycle.
  * PlayerManager: Move the start/restart handler where it belongs.
  * PlayerManager: Always perform setup on construction.
  * WebImageFetcher: check better last.fm results
  * LyricWiki: link to the actual lyrics page (kde#332664)
  * Fix minor EBN issues
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * systray: Make SHIFT+Mousewheel change the volume, not the song. (kde#250355)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * WebImageFetcher: properly destroy dialog after any request
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Set the tick interval, because the default value is 0 (kde#389907)
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Bring back inline tag editing. (kde#395948)
  * use KDE_INSTALL_METAINFODIR
  * Remove slight bias in random track selection.
  * Inhibit power management when playing audio.
  * Do not duplicate work of KAboutData::setupCommandLine()
  * Fix one warning because of deprecated API call
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * use KDE_INSTALL_METAINFODIR
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * systray: Ensure quit from systray also saves config changes.
  * Simplify shutdown handling. (kde#388663)
  * Don't try to start in docked mode without the systray.
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Extract Playlist::SharedSettings into a separate file.
  * Stop playback before taking shutdown actions.
  * More column-handling bugfixes in Playlist.
  * Fix columns sorting. (kde#389130)
  * Avoid crash on tree view mode by disabling tree view mode :( (kde#389937)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Immediately update dynamic/search playlist items upon a change. (kde#389176)
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * None
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Fix build when tunepimp is available.
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Fix: remove a shortcut conflict between two actions
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * None
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Mon Jul 24 2017 tchvatal@suse.com
- Drop dependency over libtunepimp:
  * musicbrainz api that is no longer supported, would need porting
    to new musicbrainz libraries
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * None
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * None
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * None
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Wed Aug 19 2015 cgiboudeaux@gmx.com
- Update to KDE Applications 15.08.0
  * KDE Applications 15.08.0
  * https://www.kde.org/announcements/announce-applications-15.08.0.php
* Fri Aug  7 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.07.90
  * KDE Applications 15.08.0 RC1
  * https://www.kde.org/announcements/announce-applications-15.08-rc.php
* Mon Jul  6 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.3
  * KDE Applications 15.04.3
  * https://www.kde.org/announcements/announce-applications-15.04.3.php
* Sat May 30 2015 tittiatcoke@gmail.com
- Update
* Mon May 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.1
  * KDE Applications 15.04.1
  * https://www.kde.org/announcements/announce-applications-15.04.1.php
* Sat Apr 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.04.0
  * KDE Applications 15.04.0
  * https://www.kde.org/announcements/announce-applications-15.04.0.php
* Sat Mar 21 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.95
  * KDE Applications 15.04 RC
* Sun Mar  8 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.03.80
  * KDE Applications 15.04 Beta
* Tue Mar  3 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.3
  * KDE Applications 14.12.3
  * See https://www.kde.org/announcements/announce-applications-14.12.3.php
* Sun Feb  1 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.2
  * KDE Applications 14.12.2
  * See https://www.kde.org/announcements/announce-applications-14.12.2.php
* Mon Jan 12 2015 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.1
  * KDE Applications 14.12.1
  * See https://www.kde.org/announcements/announce-applications-14.12.1.php
* Wed Dec 17 2014 tittiatcoke@gmail.com
- Update to KDE Applications 14.12.0
  * KDE Applications 14.12.0
  * See https://www.kde.org/announcements/announce-applications-14.12.0.php
* Sun Nov  9 2014 tittiatcoke@gmail.com
- Update to 4.14.3
  * KDE 4.14.3 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.3.php
* Sun Oct 12 2014 tittiatcoke@gmail.com
- Update to 4.14.2
  * KDE 4.14.2 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.2.php
* Sat Sep 13 2014 tittiatcoke@gmail.com
- Update to 4.14.1
  * KDE 4.14.1 SC Bugfix Release
  * See http://www.kde.org/announcements/announce-4.14.1.php
* Fri Aug 15 2014 tittiatcoke@gmail.com
- Update to 4.14.0
  * KDE 4.14.0 SC Final Release
  * See http://www.kde.org/announcements/4.14/
* Thu Jul 17 2014 cgiboudeaux@gmx.com
- Update to 4.13.90
  * KDE 4.14 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.14-beta2.php
- Drop 0001-fix-the-appdata-dir.patch (merged upstream)
* Thu Jul 10 2014 cgiboudeaux@gmx.com
- Update to 4.13.80
  * KDE 4.14 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.14-beta1.php
- Add 0001-fix-the-appdata-dir.patch (Fix the appdata file location)
* Sun Jun  8 2014 tittiatcoke@gmail.com
- Update to 4.13.2
  * KDE 4.13  release
  * See http://www.kde.org/announcements/announce-4.13.2.php
* Fri May  9 2014 tittiatcoke@gmail.com
- Update to 4.13.1
  * KDE 4.13.1  bug fix release
  * See http://www.kde.org/announcements/announce-4.13.1.php
* Fri Apr 11 2014 tittiatcoke@gmail.com
- Update to 4.13.0
  * KDE 4.13  release
  * See http://www.kde.org/announcements/4.13/
* Thu Mar 27 2014 tittiatcoke@gmail.com
- Update to 4.12.97
  * KDE 4.13 RC  release
  * See http://www.kde.org/announcements/announce-4.13-rc.php
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 4.12.95
  * KDE 4.13 Beta 3  release
  * See http://www.kde.org/announcements/announce-4.13-beta3.php
* Thu Mar 13 2014 tittiatcoke@gmail.com
- Update to 4.12.90
  * KDE 4.13 Beta 2  release
  * See http://www.kde.org/announcements/announce-4.13-beta2.php
* Fri Mar  7 2014 tittiatcoke@gmail.com
- Update to 4.12.80
  * KDE 4.13 Beta 1  release
  * See http://www.kde.org/announcements/announce-4.13-beta1.php
* Sat Feb  1 2014 tittiatcoke@gmail.com
- Update to 4.12.2
  * KDE 4.12.2  release
  * See http://www.kde.org/announcements/announce-4.12.2.php
* Sat Jan 11 2014 tittiatcoke@gmail.com
- Update to 4.12.1
  * KDE 4.12.1  release
  * See http://www.kde.org/announcements/announce-4.12.1.php
* Sat Dec 14 2013 tittiatcoke@gmail.com
- Update to 4.12.0
  * KDE 4.12.0  release
  * See http://www.kde.org/announcements/4.12.php
* Fri Nov 29 2013 tittiatcoke@gmail.com
- Update to 4.11.97
  * KDE 4.12 RC 1 release
  * See http://www.kde.org/announcements/announce-4.12-rc.php
* Sat Nov 23 2013 tittiatcoke@gmail.com
- Update to 4.11.95
  * KDE 4.12 Beta 3 release
  * See http://www.kde.org/announcements/announce-4.12-beta3.php
* Sat Nov 16 2013 tittiatcoke@gmail.com
- Update to 4.11.90
  * KDE 4.12 Beta 2 release
  * See http://www.kde.org/announcements/announce-4.12-beta2.php
* Sat Nov  9 2013 tittiatcoke@gmail.com
- Update to 4.11.80
  * KDE 4.12 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.12-beta1.php
* Sat Nov  2 2013 tittiatcoke@gmail.com
- Update to 4.11.3
  * KDE 4.11.3 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.3.php
* Sat Sep 28 2013 tittiatcoke@gmail.com
- Update to 4.11.2
  * KDE 4.11.2 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.2.php
* Sun Sep  1 2013 tittiatcoke@gmail.com
- Update to 4.11.1
  * KDE 4.11.1 bugfix release
  * See http://www.kde.org/announcements/announce-4.11.1.php
* Thu Aug  8 2013 tittiatcoke@gmail.com
- Update to 4.11.0
  * KDE 4.11 Final release
  * See http://www.kde.org/announcements/4.11/
* Thu Jul 25 2013 hrvoje.senjan@gmail.com
- Update to 4.10.97
  * KDE 4.11 RC 2 release
  * See http://www.kde.org/announcements/announce-4.11-rc2.php
* Mon Jul 15 2013 cgiboudeaux@gmx.com
- Update to 4.10.95
  * KDE 4.11 RC 1 release
  * See http://www.kde.org/announcements/announce-4.11-rc1.php
* Thu Jun 27 2013 tittiatcoke@gmail.com
- Update to 4.10.90
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta2.php
* Thu Jun 13 2013 tittiatcoke@gmail.com
- Update to 4.10.80
  * KDE 4.11 Beta 1 release
  * See http://www.kde.org/announcements/announce-4.11-beta1.php
* Sat Jun  1 2013 tittiatcoke@gmail.com
- Update to 4.10.4
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.4.php
  * resolves bnc#8122760
* Sat May  4 2013 tittiatcoke@gmail.com
- Update to 4.10.3
  * Bugfix release
  * See http://www.kde.org/announcements/announce-4.10.3.php
  * resolves bnc#818500
* Mon Apr  1 2013 tittiatcoke@gmail.com
- Update to 4.10.2 \n  * Bugfixes
* Sat Mar  2 2013 tittiatcoke@gmail.com
- Update to 4.10.1
  * Contains bug fixes. See http://www.kde.org/announcements/
  for more information
* Thu Jan 31 2013 tittiatcoke@gmail.com
- Update to 4.10.0
  * This is the final release for 4.10. Contains bugfixes
* Thu Jan 17 2013 tittiatcoke@gmail.com
- Update to 4.9.98
  * This is the third RC release for 4.10. Contains bugfixes
* Thu Jan  3 2013 tittiatcoke@gmail.com
- Update to 4.9.97
  * This is the second RC release for 4.10. Contains bugfixes
* Wed Dec 19 2012 tittiatcoke@gmail.com
- Update to 4.9.95
  * This is the first RC release for 4.10. Contains bugfixes
* Sat Dec  1 2012 tittiatcoke@gmail.com
- Update to 4.9.90
  * This is the second Beta release for 4.10. Contains bugfixes
* Sat Nov 24 2012 tittiatcoke@gmail.com
- Update to 4.9.80
  * See http://www.kde.org/announcements/announce-4.10-beta1.php
  * Add Lyrics view
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Fri Nov  2 2012 tittiatcoke@gmail.com
- Update to 4.9.3
  * see http://kde.org/announcements/announce-4.9.3.php for details
* Sat Sep 29 2012 tittiatcoke@gmail.com
- Update to 4.9.2
  * see http://kde.org/announcements/announce-4.9.2.php for details
* Tue Sep  4 2012 toddrme2178@gmail.com
- Update to 4.9.1
  * see http://kde.org/announcements/4.9.1/ for details
* Tue Jul 31 2012 toddrme2178@gmail.com
- Update to 4.9.0
  * see http://kde.org/announcements/4.9/ for details
* Thu Jul 19 2012 toddrme2178@gmail.com
- update to 4.8.97
  * RC2 milestone release of KDE 4.9
  * see http://kde.org/announcements/announce-4.9-rc2.php for details
* Fri Jun 29 2012 tittiatcoke@gmail.com
- Update to 4.8.95_20120629
* Sun Jun 17 2012 tittiatcoke@gmail.com
- Update to 4.8.90_20120617
* Tue May 29 2012 tittiatcoke@gmail.com
- Update to 4.8.80_20120529
* Sun May 13 2012 tittiatcoke@gmail.com
- Update to 4.8.42_20120513
* Sun May  6 2012 tittiatcoke@gmail.com
- Update to 4.8.42_20120506
* Tue Nov 22 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111122
* Sun Nov 20 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111120
* Fri Nov 18 2011 tittiatcoke@gmail.com
- Update to 4.7.80_20111118
* Wed Nov 16 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111116
* Tue Nov 15 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111115
* Mon Nov 14 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111114
* Sun Nov 13 2011 tittiatcoke@gmail.com
- Update to 4.7.46_20111113
* Fri Nov 11 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111111
* Mon Nov  7 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111107
* Sun Nov  6 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111106
* Fri Nov  4 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111104
* Thu Nov  3 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111103
* Tue Nov  1 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111101
* Mon Oct 31 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111031
* Sat Oct 29 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111029
* Fri Oct 28 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111028
* Wed Oct 26 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111026
* Tue Oct 25 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111025
* Mon Oct 24 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111024
* Sun Oct 23 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111023
* Fri Oct 21 2011 tittiatcoke@gmail.com
- Update to 4.7.45_20111021
* Wed Oct 19 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111019
* Tue Oct 18 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111018
* Mon Oct 17 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111017
* Mon Oct 17 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111017
* Sun Oct 16 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111016
* Sat Oct 15 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111015
* Fri Oct 14 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111014
* Thu Oct 13 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111013
* Wed Oct 12 2011 tittiatcoke@gmail.com
- Update to 4.7.44_20111012
* Tue Oct 11 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111011
* Mon Oct 10 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111010
* Sun Oct  9 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111009
* Fri Oct  7 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111007
* Wed Oct  5 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111005
* Tue Oct  4 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111004
* Mon Oct  3 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111003
* Sun Oct  2 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111002
* Sat Oct  1 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20111001
* Thu Sep 29 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20110929
* Wed Sep 28 2011 tittiatcoke@gmail.com
- Update to 4.7.43_20110928
* Tue Sep 27 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110927
* Sun Sep 25 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110925
* Sat Sep 24 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110924
* Thu Sep 22 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110922
* Wed Sep 21 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110921
* Tue Sep 20 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110920
* Sun Sep 18 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110918
* Fri Sep 16 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110916
* Thu Sep 15 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110915
* Tue Sep 13 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110913
* Tue Sep 13 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110913
* Mon Sep 12 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110912
* Mon Sep 12 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110912
* Fri Sep  9 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110909
* Wed Sep  7 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110907
* Tue Sep  6 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110906
* Sun Sep  4 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110904
* Sat Sep  3 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110903
* Fri Sep  2 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110902
* Thu Sep  1 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110901
* Tue Aug 30 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110830
* Mon Aug 29 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110829
* Sun Aug 28 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110828
* Sat Aug 27 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110827
* Fri Aug 26 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110826
* Thu Aug 25 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110825
* Tue Aug 23 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110823
* Mon Aug 22 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110822
* Sun Aug 21 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110821
* Sat Aug 20 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110820
* Fri Aug 19 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110819
* Thu Aug 18 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110818
* Wed Aug 17 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110817
* Wed Aug 17 2011 tittiatcoke@gmail.com
- Update to 4.7.42_20110817
* Tue Aug 16 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110816
* Thu Aug 11 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110811
* Wed Aug 10 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110810
* Tue Aug  9 2011 tittiatcoke@gmail.com
- Update to 4.7.41_20110809
* Sun Aug  7 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110807
* Fri Aug  5 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110805
* Thu Aug  4 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110804
* Wed Aug  3 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110803
* Tue Aug  2 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110802
* Tue Aug  2 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110802
* Mon Aug  1 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110801
* Fri Jul 29 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110729
* Wed Jul 27 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110727
* Mon Jul 25 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110725
* Sun Jul 24 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110724
* Sun Jul 24 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110724
* Fri Jul 22 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110722
* Thu Jul 21 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110721
* Thu Jul 21 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110721
* Wed Jul 20 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110720
* Tue Jul 19 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110719
* Mon Jul 18 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110718
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110717
* Thu Jul 14 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110714
* Mon Jul  4 2011 tittiatcoke@gmail.com
- Update to 4.7.40_20110704
* Tue Jun 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110621
* Mon Jun 20 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110620
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Sat Jun 18 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110618
* Wed Jun 15 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110615
* Tue Jun 14 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110614
* Mon Jun 13 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110613
* Sun Jun 12 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110612
* Sat Jun 11 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110611
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Thu Jun  9 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110609
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Wed Jun  8 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110608
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Tue Jun  7 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110607
* Mon Jun  6 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110606
* Sun Jun  5 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110605
* Sat Jun  4 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110604
* Fri Jun  3 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110603
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Thu Jun  2 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110602
* Wed Jun  1 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110601
* Tue May 31 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110531
* Mon May 30 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110530
* Sat May 28 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110528
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Fri May 27 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110527
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Thu May 26 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110526
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110525
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Tue May 24 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110524
* Mon May 23 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110523
* Sat May 21 2011 tittiatcoke@gmail.com
- Update to 4.6.80_20110521
* Fri May 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110520
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Thu May 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110519
* Wed May 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110518
* Tue May 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110517
* Mon May 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110516
* Sun May 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110515
* Sat May 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110514
* Fri May 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110513
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Thu May 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110512
* Wed May 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110511
* Tue May 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110510
* Mon May  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110509
* Sun May  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110508
* Sat May  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110507
* Fri May  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110506
* Thu May  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110505
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Wed May  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110504
* Tue May  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110503
* Mon May  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110502
* Sat Apr 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110430
* Fri Apr 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110429
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110428
* Sat Apr 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110423
* Fri Apr 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110422
* Thu Apr 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110421
* Wed Apr 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110420
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110419
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110418
* Sat Apr 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110416
* Fri Apr 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110415
* Thu Apr 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110414
* Wed Apr 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110413
* Tue Apr 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110412
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110411
* Mon Apr 11 2011 tittiatcoke@gmail.com
- Update to .._20110411
* Sun Apr 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110410
* Sat Apr  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110409
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110408
* Thu Apr  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110407
* Wed Apr  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110406
* Tue Apr  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110405
* Mon Apr  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110404
* Sun Apr  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110403
* Fri Apr  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110401
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110331
* Wed Mar 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110330
* Tue Mar 29 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110329
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110328
* Thu Mar 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110324
* Wed Mar 23 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110323
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Mon Mar 21 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110321
* Sat Mar 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110319
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110318
* Thu Mar 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110317
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110316
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Tue Mar 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110315
* Mon Mar 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110314
* Sun Mar 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110313
* Sat Mar 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110312
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110311
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Thu Mar 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110310
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110309
* Tue Mar  8 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110308
* Mon Mar  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110307
* Sun Mar  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110306
* Sat Mar  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110305
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110304
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Thu Mar  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110303
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110302
* Tue Mar  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110301
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Mon Feb 28 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110228
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110227
* Sat Feb 26 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110226
* Fri Feb 25 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110225
* Thu Feb 24 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110224
* Tue Feb 22 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110222
* Sun Feb 20 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110220
* Sat Feb 19 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110219
* Fri Feb 18 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110218
* Thu Feb 17 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110217
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110216
* Tue Feb 15 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110215
* Mon Feb 14 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110214
* Sun Feb 13 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110213
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Sat Feb 12 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110212
* Thu Feb 10 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110210
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Wed Feb  9 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110209
* Mon Feb  7 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110207
* Sun Feb  6 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110206
* Sat Feb  5 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110205
* Fri Feb  4 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110204
* Thu Feb  3 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110203
* Wed Feb  2 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110202
* Tue Feb  1 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110201
* Mon Jan 31 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110131
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Sun Jan 30 2011 tittiatcoke@gmail.com
- Update to 4.6.41_20110130
* Wed Jan  5 2011 dmueller@suse.de
- update to 4.6.41_20110106
* Sun Dec 19 2010 tittiatcoke@gmail.com
- Update to 4.5.86svn1207757
* Fri Dec 10 2010 dmueller@suse.de
- update to 4.5.86svn1205247
* Wed Dec  1 2010 dmueller@suse.de
- update to 4.5.82svn1202688
* Mon Nov 29 2010 tittiatcoke@gmail.com
- Update to 4.5.81svn1202101
* Sun Nov 21 2010 coolo@novell.com
- remove patch not adapted since 4.1
* Fri Nov 19 2010 dmueller@suse.de
- update to 4.5.80
  * KDE 4.6 Beta1
  * no upstream changelog available.
* Thu Oct 28 2010 dmueller@suse.de
- update to 4.5.3
  * see http://kde.org/announcements/changelogs/changelog4_5_2to4_5_3.php for details
* Thu Sep 30 2010 dmueller@suse.de
- update to 4.5.2
  * see http://kde.org/announcements/changelogs/changelog4_5_1to4_5_2.php for details
* Fri Aug 27 2010 dmueller@suse.de
- update to 4.5.1
  * see http://kde.org/announcements/changelogs/changelog4_5_0to4_5_1.php for details
* Thu Jul 29 2010 dmueller@suse.de
- update to 4.5.0
  * KDE 4.5.0 final (version bump over RC3)
* Tue Jul 27 2010 coolo@novell.com
- libakode doesn't seem to be required
* Fri Jul 23 2010 dmueller@suse.de
- update to 4.4.95
  * KDE 4.5 RC3 (not announced)
  * critical fixes for 4.5.0 release
* Fri Jul 16 2010 dmueller@suse.de
- update to 4.4.93svn1149349
* Wed Jul  7 2010 dmueller@suse.de
- update to 4.4.5
  * bugfixes over 4.4.4
  * see http://kde.org/announcements/changelogs/changelog4_4_4to4_4_5.php for details
* Fri Jun 18 2010 dmueller@suse.de
- update to 4.4.4
  * bugfixes over 4.4.3
  * see http://kde.org/announcements/changelogs/changelog4_4_3to4_4_ 4.php for details
  * for most modules only version number as a change (4_4_BRANCH.diff already contained the diff
* Wed May 19 2010 cmorve69@yahoo.es
- Remove __DATE__ from source so build-compare can do its work
* Mon May 17 2010 llunak@novell.com
- update 4_4_BRANCH.diff: various fixes, translation updates
* Thu Apr 29 2010 dmueller@suse.de
- update to 4.4.3
  * bugfixes over 4.4.2
  * see http://kde.org/announcements/changelogs/changelog4_4_2to4_4_3.php for details
* Fri Mar 26 2010 dmueller@suse.de
- update to 4.4.2
  * bugfixes over 4.4.1
  * see http://kde.org/announcements/changelogs/changelog4_4_1to4_4_2.php for details
* Fri Feb 26 2010 dmueller@suse.de
- update to 4.4.1
  * bugfixes over 4.4.0
  * see http://kde.org/announcements/changelogs/changelog4_4_0to4_4_1.php for details
* Thu Feb  4 2010 dmueller@suse.de
- update to 4.4.0
  * Critical bugfixes only over 4.3.98
  * see http://www.kde.org/announcements/4.4/ for general overview
* Sun Jan 31 2010 dmueller@suse.de
- update to 4.3.98
  * see http://www.kde.org/announcements/announce-4.4-rc3.php for details
* Thu Jan 28 2010 adrian@suse.de
- require cdparanoia-devel also for openSUSE:11.2
  (enables kio_audiocd again)
* Wed Jan 20 2010 dmueller@suse.de
- update to 4.3.95
  * see http://www.kde.org/announcements/announce-4.4-rc2.php for details
* Wed Jan  6 2010 dmueller@suse.de
- update to 4.3.90
  * see http://www.kde.org/announcements/announce-4.4-rc1.php for details
* Fri Dec 18 2009 dmueller@suse.de
- update to 4.3.85
  * see http://www.kde.org/announcements/announce-4.4-beta2.php for details
* Fri Dec  4 2009 dmueller@suse.de
- update to 4.3.80:
  * see http://techbase.kde.org/Schedules/KDE4/4.4_Feature_Plan
* Mon Nov 16 2009 llunak@novell.com
- obsolete only old versions of kdemultimedia3-kmix (bnc#542094)
* Mon Nov  2 2009 dmueller@suse.de
- update to 4.3.3
  * see http://kde.org/announcements/changelogs/changelog4_3_2to4_3_3.php for details
* Thu Oct 22 2009 crrodriguez@opensuse.org
- fix Provides/Obsoletes of kmix
* Thu Sep 24 2009 beineri@opensuse.org
- update 4_3_BRANCH.diff: few bug fixes and translation updates
* Fri Aug 28 2009 dmueller@suse.de
- update to 4.3.1
  * see http://kde.org/announcements/changelogs/changelog4_3_0to4_3_1.php for details
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Sat Aug 15 2009 beineri@opensuse.org
- fix menu categories of juk and dragonplayer (for smaller menu)
* Mon Aug 10 2009 beineri@opensuse.org
- remove libpulse-devel build requires
* Fri Aug  7 2009 llunak@suse.cz
- solid action for audiocd:/ (bnc#505997)
* Wed Jul 29 2009 dmueller@suse.de
- update to 4.3.0
  * see http://kde.org/announcements/4.3 for details
* Tue Jul 21 2009 dmueller@suse.de
- update to 4.2.98
* Wed Jul  8 2009 wstephenson@suse.de
- Update BuildRequires for new cdparanoia-devel
* Wed Jul  8 2009 dmueller@suse.de
- update to 4.2.96
* Wed Jun 24 2009 dmueller@suse.de
- update to 4.2.95
* Sat Jun 20 2009 beineri@opensuse.org
- drop kde4- package prefixes
* Wed Jun  3 2009 dmueller@suse.de
- update to 4.2.90
* Wed May 27 2009 dmueller@suse.de
- update to 4.2.88svn973768
* Tue May 19 2009 dmueller@suse.de
- update to 4.2.87svn969966
* Mon May 18 2009 dmueller@suse.de
- update to 4.2.86svn967995
* Thu May 14 2009 dmueller@suse.de
- update to 4.2.85 (KDE 4.3 Beta1)
* Thu May 14 2009 dmueller@suse.de
- fix versioned deps
* Thu Apr 30 2009 dmueller@suse.de
- update to 4.2.3
  * see http://kde.org/announcements/changelogs/changelog4_2_2to4_2_3.php
* Thu Mar 26 2009 dmueller@suse.de
- update to 4.2.2
  * see http://kde.org/announcements/changelogs/changelog4_2_1to4_2_2.php
* Fri Feb 27 2009 dmueller@suse.de
- update to 4.2.1
  * see http://kde.org/announcements/changelogs/changelog4_2_0to4_2_1.php
* Thu Jan 22 2009 dmueller@suse.de
- update to 4.2.0
* Fri Jan 16 2009 dmueller@suse.de
- fix versioned deps
* Tue Jan 13 2009 dmueller@suse.de
- update to 4.1.96
* Fri Jan  9 2009 dmueller@suse.de
- update to 4.1.87 (KDE 4.2 Januar snapshot)
* Tue Dec 16 2008 stbinner@suse.de
- versionized split-provides are not supported
* Thu Nov 20 2008 stbinner@suse.de
- add SLE provides/obsoletes
* Wed Nov  5 2008 dmueller@suse.de
- add missing runtime requires for dragonplayer
* Tue Nov  4 2008 llunak@suse.cz
- assign multimedia volume shortcuts to KMix (bnc#384745)
* Fri Oct 31 2008 dmueller@suse.de
- update to 4.1.3
  * see http://kde.org/announcements/changelogs/changelog4_1_2to4_1_3.php
* Thu Sep 25 2008 dmueller@suse.de
- update to 4.1.2
  * see http://kde.org/announcements/changelogs/changelog4_1_1to4_1_2.php
* Mon Sep 15 2008 dmueller@suse.de
- fix requires
* Thu Aug 28 2008 dmueller@suse.de
- update to 4.1.1
  * see http://kde.org/announcements/changelogs/changelog4_1to4_1_1.php
* Wed Jul 23 2008 dmueller@suse.de
- update to 4.1.0
* Thu Jul 17 2008 dmueller@suse.de
- update to 4.0.99
* Fri Jul 11 2008 dmueller@suse.de
- update to 4.0.98
* Thu Jul  3 2008 dmueller@suse.de
- update to 4.0.85
* Thu Jun 26 2008 dmueller@suse.de
- update to 4.0.84
* Wed Jun 18 2008 dmueller@suse.de
- update to 4.0.83
* Tue Jun 10 2008 dmueller@suse.de
- update to 4.0.82
* Mon Jun  9 2008 dmueller@suse.de
- update to 4.0.81
* Fri May  9 2008 dmueller@suse.de
- 4_0_BRANCH.diff update:
  * remove kio progress popups in juk
* Thu May  1 2008 dmueller@suse.de
- update to 4.0.4
  * http://www.kde.org/announcements/changelogs/changelog4_0_3to4_0_4.php
* Fri Apr 18 2008 dmueller@suse.de
- another 4_0_BRANCH.diff update:
  * hopefully fixes kmix crash on exit (bnc#373639)
* Mon Apr 14 2008 dmueller@suse.de
- 4_0_BRANCH.diff update
* Thu Mar 27 2008 dmueller@suse.de
- update to 4.0.3
* Wed Feb 27 2008 dmueller@suse.de
- update to 4.0.2
* Fri Feb 15 2008 dmueller@suse.de
- update 4_0_BRANCH.diff
* Mon Feb  4 2008 stbinner@suse.de
- port kmix-autostart.diff
* Thu Jan 31 2008 dmueller@suse.de
- update to 4.0.1
* Sun Jan 20 2008 stbinner@suse.de
- update KDE_4_0_BRANCH.diff
* Sat Jan  5 2008 stbinner@suse.de
- update to 4.0 release
* Wed Jan  2 2008 stbinner@suse.de
- update to 3.97.2
* Sun Dec 16 2007 dmueller@suse.de
- update to 3.97.1
* Wed Dec  5 2007 dmueller@suse.de
- update to 3.97.0
* Tue Dec  4 2007 dmueller@suse.de
- update to 3.96.3
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.2
* Wed Nov 21 2007 dmueller@suse.de
- update to 3.96.1
* Wed Nov 14 2007 dmueller@suse.de
- update to 3.96.0
* Wed Nov  7 2007 dmueller@suse.de
- update to 3.95.2
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.1
* Fri Oct 26 2007 dmueller@suse.de
- update to KDE 4.0 beta4
* Sat Oct 20 2007 dmueller@suse.de
- update to 3.94.1
* Tue Oct  9 2007 dmueller@suse.de
- update to KDE 4.0 Beta3
* Tue Oct  2 2007 stbinner@suse.de
- update to 3.93.0.svn720130
* Wed Sep 26 2007 stbinner@suse.de
- update to 3.93.0.svn717255
* Thu Sep 13 2007 stbinner@suse.de
- update to 3.93.0.svn712059
* Sat Sep  1 2007 stbinner@suse.de
- update to KDE 4.0 Beta 2
* Thu Aug 23 2007 stbinner@suse.de
- update to 3.92.0.svn703910
* Thu Aug 16 2007 stbinner@suse.de
- update to 3.92.0.svn700761
* Thu Aug  9 2007 stbinner@suse.de
- update to 3.92.0.svn697375
* Sun Jul 29 2007 stbinner@suse.de
- update to KDE 4.0 Beta 1
* Thu Jul 12 2007 stbinner@suse.de
- update to 3.91.0.svn685969
* Sat Jun 23 2007 stbinner@suse.de
- update to 3.90.1.svn679140
* Wed Jun 13 2007 stbinner@suse.de
- disable build of Noatun's splitplaylist (#276925)
* Fri Jun  8 2007 stbinner@suse.de
- update to 3.90.1.svn670093
* Fri Jun  1 2007 coolo@suse.de
- simplify spec file by using macros from kde4-filesystem
* Fri May 25 2007 stbinner@suse.de
- split off -devel package
* Fri May 18 2007 stbinner@suse.de
- initial version in abuild
